fold_highest_var_inplace

Function fold_highest_var_inplace 

pub fn fold_highest_var_inplace<P: PackedField, Data: BufferData<P>>(
    values: &mut FieldBuffer<P, Data>,
    scalar: P::Scalar,
)
Fixes the highest variable of a multilinear to a value, in place.

g(X_0, ..., X_{n-2}) = f(X_0, ..., X_{n-2}, r)

The result occupies the first half of the buffer. The buffer then reports one variable fewer.

Preconditions

  • the buffer must have at least one variable